@@ -1,8 +1,10 @@
 from enum import Enum, EnumMeta
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Union, Tuple
 
 from requests import Response
 
+
 class ClientType(object):
-    '''Abstract class for client'''
+    """Abstract class for client"""
+
     pass
